"""Django App configuration for socialprofile"""

from django.apps import AppConfig

class SocialProfileConfig(AppConfig):

    """Default configuration for socialprofile"""

    name = 'socialprofile'
    verbose_name = "Social Profile"