# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-10 01:57
from __future__ import unicode_literals

from django.db import migrations
import user_sessions.models


class Migration(migrations.Migration):

    dependencies = [
        ('axes', '0003_auto_20160322_0929'),
        ('social_django', '0006_partial'),
        ('otp_totp', '0001_initial'),
        ('user_sessions', '0003_auto_20161205_1516'),
        ('two_factor', '0005_auto_20160224_0450'),
        ('otp_static', '0001_initial'),
        ('socialprofile', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProxyAccessAttempt',
            fields=[
            ],
            options={
                'verbose_name': 'Monitor: access attempt',
                'proxy': True,
                'verbose_name_plural': 'Monitor: access attempts',
                'indexes': [],
            },
            bases=('axes.accessattempt',),
        ),
        migrations.CreateModel(
            name='ProxyAccessLog',
            fields=[
            ],
            options={
                'verbose_name': 'Monitor: access log',
                'proxy': True,
                'verbose_name_plural': 'Monitor: access logs',
                'indexes': [],
            },
            bases=('axes.accesslog',),
        ),
        migrations.CreateModel(
            name='ProxyAssociation',
            fields=[
            ],
            options={
                'verbose_name': 'OAuth: association',
                'proxy': True,
                'verbose_name_plural': 'OAuth: associations',
                'indexes': [],
            },
            bases=('social_django.association',),
        ),
        migrations.CreateModel(
            name='ProxyNonce',
            fields=[
            ],
            options={
                'verbose_name': 'OAuth: nonce',
                'proxy': True,
                'verbose_name_plural': 'OAuth: nonces',
                'indexes': [],
            },
            bases=('social_django.nonce',),
        ),
        migrations.CreateModel(
            name='ProxyPhoneDevice',
            fields=[
            ],
            options={
                'verbose_name': 'Otp: phone device',
                'proxy': True,
                'verbose_name_plural': 'Otp: phone devices',
                'indexes': [],
            },
            bases=('two_factor.phonedevice',),
        ),
        migrations.CreateModel(
            name='ProxySession',
            fields=[
            ],
            options={
                'verbose_name': 'Monitor: sessione',
                'proxy': True,
                'verbose_name_plural': 'Monitor: sessioni',
                'indexes': [],
            },
            bases=('user_sessions.session',),
            managers=[
                ('objects', user_sessions.models.SessionManager()),
            ],
        ),
        migrations.CreateModel(
            name='ProxyStaticDevice',
            fields=[
            ],
            options={
                'verbose_name': 'Otp: static device',
                'proxy': True,
                'verbose_name_plural': 'Otp: static devices',
                'indexes': [],
            },
            bases=('otp_static.staticdevice',),
        ),
        migrations.CreateModel(
            name='ProxyTOTPDevice',
            fields=[
            ],
            options={
                'verbose_name': 'Otp: TOTP device',
                'proxy': True,
                'verbose_name_plural': 'Otp: TOTP devices',
                'indexes': [],
            },
            bases=('otp_totp.totpdevice',),
        ),
        migrations.CreateModel(
            name='ProxyUserSocialAuth',
            fields=[
            ],
            options={
                'verbose_name': 'OAuth: user social auth',
                'proxy': True,
                'verbose_name_plural': 'OAuth: user social auths',
                'indexes': [],
            },
            bases=('social_django.usersocialauth',),
        ),
    ]
